@@ -9,13 +9,14 @@
 
 #define ap_GetCAPIStaticMap_fcn CAT(CAPI_MDL,_GetCAPIStaticMap)
 
+#define M_PI (3.14159265354)
+
 #include <iostream>
 #include <fstream>
 #include <vector>
 #include <regex>
 #include <string>
 
-
 std::vector<std::string> scan_param(uav_fdmModelClass *Obj)
 {
     std::vector<std::string> head;
@@ -162,12 +163,13 @@ void setup_param(uav_fdmModelClass *Obj, const std::vector<std::string> &head, c
     }
 }
 
+const double lat2m = 110574.2727;
+const double lon2m = 111319.46;
 
-uav_fdm::uav_fdm(double lat0, double lon0, double alt0,
+uav_fdm::uav_fdm(double x0, double y0, double alt0,
             double gs0, double gamma0, double psi0, double phi0)
 {
     fdm3d = new uav_fdmModelClass;
-    fdm3d->initialize();
 
         std::cout << "Parameters in the mdl:" << std::endl;
         std::vector<std::string> heads = scan_param(fdm3d);
@@ -178,9 +180,9 @@ uav_fdm::uav_fdm(double lat0, double lon0, double alt0,
         std::vector<std::string> param_name;
         std::vector<double> param_val;
         param_name.push_back("LatLon0");
-        param_val.push_back(lat0);
+        param_val.push_back(x0/lat2m);
         param_name.push_back("LatLon0(1)");
-        param_val.push_back(lon0);
+        param_val.push_back(y0/lat2m);
         param_name.push_back("Alt0");
         param_val.push_back(alt0);
         param_name.push_back("gs0");
@@ -192,12 +194,14 @@ uav_fdm::uav_fdm(double lat0, double lon0, double alt0,
         param_name.push_back("phi0");
         param_val.push_back(phi0);
         setup_param(fdm3d, param_name, param_val);
+
+    fdm3d->initialize();
 }
 
-void uav_fdm::update(double dt, double tas_c, double hdot_c, double phi_c,
+void uav_fdm::update(double dt, double tas_c, double hdot_c, double psi_c,
                 double w_n, double w_e,
                 double *time_stamp,
-                double *lat, double *lon, double *alt,
+                double *x, double *y, double *alt,
                 double *v_n, double *v_e, double *hdot,
                 double *phi, 
                 double *psi_t, double *gamma, double *gs,
@@ -206,15 +210,31 @@ void uav_fdm::update(double dt, double tas_c, double hdot_c, double phi_c,
     double t0 = fdm3d->uav_fdm3d_Y.time_stamp;
     fdm3d->uav_fdm3d_U.tas_c = tas_c;
     fdm3d->uav_fdm3d_U.hdot_c = hdot_c;
-    fdm3d->uav_fdm3d_U.phi_c = phi_c;
     fdm3d->uav_fdm3d_U.w_n = w_n;
     fdm3d->uav_fdm3d_U.w_e = w_e;
+    double phi_c;
+    double dpsi = psi_c - fdm3d->uav_fdm3d_Y.psi_t;
+    while (dpsi > M_PI)
+    {
+        dpsi -= 2 * M_PI;
+    }
+    while (dpsi < -M_PI)
+    {
+        dpsi += 2 * M_PI;
+    }
+    double as_c = dpsi * fdm3d->uav_fdm3d_Y.gs;
+    if (as_c > 5)
+        as_c = 5;
+    else if (as_c < -5)
+        as_c = -5;
+    fdm3d->uav_fdm3d_U.phi_c = atan2(as_c, 9.8);
+
     do {
       fdm3d->step();
       *time_stamp = fdm3d->uav_fdm3d_Y.time_stamp;
     } while (*time_stamp - t0 < dt);
-    *lat = fdm3d->uav_fdm3d_Y.lat;
-    *lon = fdm3d->uav_fdm3d_Y.lon;
+    *x = fdm3d->uav_fdm3d_Y.lat * lat2m;
+    *y = fdm3d->uav_fdm3d_Y.lon * lon2m;
     *alt = fdm3d->uav_fdm3d_Y.ASL;
     *v_n = fdm3d->uav_fdm3d_Y.Vn;
     *v_e = fdm3d->uav_fdm3d_Y.Ve;
